@@ -148,13 +148,13 @@ def get_all_gene(trainset_dir):
         for i in gene[:-2]:
             gene_ = gene_ + i + ', '
         gene_ = gene_ + gene[-2]
-        gene_file.write(gene_)
+        gene_file.write(gene_.lower())
     return gene
 
 
 def process_data_to_same_gene(gene, root_dir, output_dir, mode):
     dataset_list = os.listdir(root_dir)
-    for l in range(len(dataset_list)):
+    for l in tqdm(range(len(dataset_list))):
         dataset = dataset_list[l]
         if '.txt' in dataset or '.csv' in dataset:
             all_data = pd.read_csv(root_dir + dataset, sep='\t')
